Index: src/mips/simulator-mips.cc |
diff --git a/src/mips/simulator-mips.cc b/src/mips/simulator-mips.cc |
index 17c18977c702fb42dd330b87571e2b4d80e8685d..0ec3e283c6617139a39387d80d8a1e83260e5a01 100644 |
--- a/src/mips/simulator-mips.cc |
+++ b/src/mips/simulator-mips.cc |
@@ -1359,9 +1359,9 @@ void Simulator::WriteB(int32_t addr, int8_t value) { |
// Returns the limit of the stack area to enable checking for stack overflows. |
uintptr_t Simulator::StackLimit() const { |
// Leave a safety margin of 256 bytes to prevent overrunning the stack when |
// pushing values. |
- return reinterpret_cast<uintptr_t>(stack_) + 256; |
+ return reinterpret_cast<uintptr_t>(stack_) + 512; |
} |
@@ -1359,9 +1359,9 @@ void Simulator::WriteB(int32_t addr, int8_t value) { |
// Returns the limit of the stack area to enable checking for stack overflows. |
uintptr_t Simulator::StackLimit() const { |
- // Leave a safety margin of 256 bytes to prevent overrunning the stack when |
+ // Leave a safety margin of 512 bytes to prevent overrunning the stack when |
// pushing values. |